@@ -2,5 +2,5 @@ use rblog::app::app;
 
 fn main() {
     pretty_env_logger::init();
-    trillium_smol::run(app());
+    trillium_tokio::run(app());
 }
